@@ -33,12 +33,12 @@ via $PATH.
 
 =head1 FUNCTION/ATTRIBUTES
 
-=head2 write_data($filename, @datasets)
+=head2 write_data($filename, $dataset)
 
 Write the $dataset to the file $filename to create a gnuplot data file. 
-Each element in $datasets should be of the form [[<c1>...<cn>],...]
+Each element in $dataset should be of the form [[<c1>...<cn>],...]
 
-The column values must not contain newline or quote marks. They can be Unicode.
+The column values must not contain newline or quote marks. They can be unicode.
 
 =head2 fun exec_commands ($c, $data)
 
